<?php

if (!class_exists('ESIG_EDD_Options')) :

    class ESIG_EDD_Options extends Esig_Edd_Settings {

        /**
         * Initialize the plugin by loading admin scripts & styles and adding a
         * settings page and menu.
         * @since     0.1
         */
        public static function Init() {
            

            //adding metabox hook here
            add_action('add_meta_boxes', array(__CLASS__, 'esig_edd_add_meta_box'));
            // triggering when edd product saveed
            add_action('save_post', array(__CLASS__, 'esig_edd_product_save'));
            // edd misc settings tab content. 
            add_filter('edd_settings_misc', array(__CLASS__, 'edd_esig_gloabal_setting'), -1);
            // add action when esig core field description hook call. 
            add_action('edd_esig_core_msg', array(__CLASS__, 'esig_edd_core_msg'), 1);
        }

        public static function esig_edd_core_msg($args) {
            include_once ESIGN_EDD_PATH . "/views/core-msg.php";
        }

        public static function edd_esig_gloabal_setting($settings) {
            $sad = new esig_edd_sad();
            $settings[] = array(
                'id' => 'edd_esig_title',
                'name' => __('E-signature Easy Digital Downloads Settings', 'esig-edd'),
                'desc' => 'he is a good boy',
                'type' => 'header',
            );

            $settings[] = array(
                'id' => 'esig_core_msg',
                //'name' => __('E-signature Easy Digital Downloads Settings', 'esig-edd'),
                //'desc'=>'he is a good boy',
                'type' => 'hook',
            );

            $settings[] = array(
                'id' => 'esign_edd_agreement_setting',
                'name' => __('Easy Digital Downloads Agreement', 'esig-edd'),
                'desc' => __('Enable', 'esig-edd'),
                'type' => 'checkbox'
            );
            // select box 
            $settings[] = array(
                'id' => 'esign_edd_signing_logic',
                'name' => __('Signing Logic', 'esig-edd'),
                'desc' => __('This Edd settings page lets you specify siging .....', 'esig-edd'),
                'type' => 'select',
                'options' => self::signing_logic(),
            );
            // select box 
            $settings[] = array(
                'id' => 'esign_edd_sad_page',
                'name' => __('Agreement Document', 'esig-edd'),
                'type' => 'select',
                'options' => $sad->esig_get_sad_pages(),
            );

            return $settings;
        }

        public static function signing_logic() {
            return array(
                "before_checkout" => "Redirect user to sign before checkout",
                "after_checkout" => "Redirect user to esign after checkout",
            );
        }

        /**
         * Save the meta when the edd product is saved.
         *
         * @param int $post_id The ID of the post being saved.
         */
        public static function esig_edd_product_save($post_id) {

            // Check if our nonce is set.
            if (!ESIG_POST('esig_edd_product_box_nonce'))
                       return $post_id;

            $nonce = ESIG_POST('esig_edd_product_box_nonce');

            // Verify that the nonce is valid.
            if (!wp_verify_nonce($nonce, 'esig_edd_product_nonce'))
                       return $post_id;

         
            // If this is an autosave, our form has not been submitted,
            // so we don't want to do anything.
            if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
                return $post_id;


            // Check if post type is not product page return 
            if ('download' != ESIG_POST('post_type'))
                return $post_id;

            // check the user permission 
            if (!current_user_can('edit_page', $post_id))
                    return $post_id;


            // Sanitize the user input.
            self::save_product_agreement($post_id, sanitize_text_field($_POST['esig_edd_agreement']));
            self::save_product_sad_page($post_id,sanitize_text_field($_POST['esign_edd_sad_page']));
            self::save_product_signing_logic($post_id, sanitize_text_field($_POST['esign_edd_sign_logic']));
           
        }

        public static function esig_edd_add_meta_box($post_type) {
            $post_types = array('download');     //limit meta box to certain post types
            if (in_array($post_type, $post_types)) {
                add_meta_box(
                        'E-signature Option'
                        , __('Esignature Option', 'edd-esig')
                        , array(__CLASS__, 'esig_edd_render_meta_box_content')
                        , $post_type
                        , 'side'
                        , 'low'
                );
            }
        }

        public static function esig_edd_render_meta_box_content($post) {
            if (!function_exists('WP_E_Sig')) {
                __('<a href="admin.php?page=esign-not-core">E-signature</a>', 'edd-esig');
                return;
            }
            $branding_template = ESIGN_EDD_PATH . "/views/edd-esig-product-view.php";

            $template_data = get_object_vars($post);

            WP_E_Sig()->view->renderPartial('', $template_data, true, '', $branding_template);
            
        }

        
    }

endif;