<?php

class Esig_Edd_Requirement {

    public static function is_required_plugin_install() {

        if (class_exists('Easy_Digital_Downloads') && class_exists('WP_E_Digital_Signature')) {
            return true;
        } else {
            return false;
        }
    }

    public static function Init() {
        // requirement msg . 
        add_filter('esig_notices_display', array(__CLASS__, 'esig_edd_requirement_msg'), 10, 1);
        add_action("after_plugin_row", array(__CLASS__, "esig_edd_core_missing"), 10, 2);
        add_filter('admin_notices', array(__CLASS__, 'esig_edd_requirement_notices'), 10, 1);
        // activation hook.
        add_action('admin_init', array(__CLASS__, 'esign_edd_after_install'));
        add_filter('plugin_row_meta', array(__CLASS__, 'about_page_action_link'), 10, 2);
        // creating menu 
        add_action('admin_menu', array(__CLASS__, 'esig_edd_adminmenu'));
        //enqueue styles
        add_action('admin_enqueue_scripts', array(__CLASS__, 'enqueue_admin_styles'), 999);
    }

    final static function esign_edd_after_install() {

        if (!is_admin()) {
            return;
        }
        if (delete_transient('_esign_edd_redirect')) {
            wp_safe_redirect(admin_url('admin.php?page=esign-edd-about'));
            exit;
        }
    }

    /**
     * Register and enqueue admin-specific style sheet.
     *
     * @since     0.1
     *
     * @return    null    Return early if no settings page is registered.
     */
    public static function enqueue_admin_styles() {

        $screen = get_current_screen();
        $admin_screens = array(
            'e-signature_page_esign-edd',
            'admin_page_esign-edd-about',
            'download_page_edd-settings',
            'download_page_esign-edd-about',
            'e-signature_page_esign-edd-about',
            'toplevel_page_esign'
        );
   
        if (in_array($screen->id, $admin_screens)) {
            
            wp_enqueue_style('esig-edd-admin-styles', ESIGN_EDD_URL . '/assets/css/esign-edd.css', array());
        }
    }

    /**
     * Easy digital download about page link in plugin page
     * @param undefined $links
     * @param undefined $file
     * 
     * @return
     */
    public static function about_page_action_link($links, $file) {


        if (strpos($file, 'edd-wpesignature.php') !== false) {
            $new_links = array(
                '<a href="' . get_admin_url(null, 'index.php?page=esign-edd-about') . '">' . __('Need help getting started?', 'esig-edd') . '</a>'
            );

            $links = array_merge($links, $new_links);
        }

        return $links;
    }

    public static function esig_edd_core_missing($plugin_file, $plugin_data) {
        
        if(self::is_required_plugin_install()){
            return ;
        }
        
        if (strpos($plugin_file, 'edd-digital-signature.php') !== false) {
            echo '<tr class="plugin-update-tr active">

       <td colspan="3" class="plugin-update colspanchange">
       <div class="update-message">
       ' . __('This plugin is missing some required plugins by <a href="https://www.approveme.com/?utm_source=wprepo&utm_medium=link&utm_campaign=easydigitaldownloads">Approve Me</a> Which is available to Business License holders <a href="https://www.approveme.com/email-limited-pricing/?utm_source=wprepo&utm_medium=link&utm_campaign=easydigitaldownloads">Purchase License Today</a>', 'edd-esig') . '

       </div> </div></td></tr>';
        }
    }

    public static function esig_edd_requirement_msg($msg) {

        if (!class_exists('Easy_Digital_Downloads')) {

            $msg .=__('<div class="error"><span class="esig-icon-esig-alert"></span><h4>Hi there! It looks like the <a href="https://wordpress.org/plugins/easy-digital-downloads/" target="_blank">Easy Digital Downloads plugin</a> is not active. You need to activate the edd plugin in order to use the E-signature Easy Digital Download add-on features.<br></h4></div>', 'edd-esig');
        }
        if (!class_exists('ESIG_SAD_Admin')) {
            $msg .=__('<div class="error"><span class="esig-icon-esig-alert"></span><h4>Hi there! It looks like the E-signature <a href="https://www.approveme.com/downloads/stand-alone-documents/?utm_source=wprepo&utm_medium=link&utm_campaign=easydigitaldownloads">Stand Alone Document</a> plugin is not active. You need to activate the Stand Alone Document add-on to use the E-signature Easy Digital Download Features.<br></h4></div>', 'edd-esig');
        }

        return $msg;
    }

    public static function esig_edd_requirement_notices() {
        $msg = '';
        if (!class_exists('Easy_Digital_Downloads')) {

            $msg .=__('<div class="error"><span class="icon-esig-alert"></span><h4>Hi there! It looks like the <a href="https://wordpress.org/plugins/easy-digital-downloads/" target="_blank">Easy Digital Downloads plugin</a> is not active. You need to activate the edd plugin in order to use the E-signature Easy Digital Download add-on features.<br></h4></div>', 'edd-esig');
        }
        if (!class_exists('ESIG_SAD_Admin')) {
            $msg .=__('<div class="error"><h4>Hi there! It looks like the E-signature <a href="https://www.approveme.com/downloads/stand-alone-documents/?utm_source=wprepo&utm_medium=link&utm_campaign=easydigitaldownloads">Stand Alone Document</a> plugin is not active. You need to activate the Stand Alone Document add-on to use the E-signature Easy Digital Download Features.<br></h4></div>', 'edd-esig');
        }

        echo $msg;
    }

    /**
     * This is method esig_usr_adminmenu
     *   Create a admin menu for esinature roles . 
     * @return mixed This is the return value description
     */
    final static function esig_edd_adminmenu() {
       
        add_submenu_page("edit.php?post_type=download", __('E-Signature', 'esig'), __('E-Signature', 'esig'), 'read', 'esign-edd-about', array(__CLASS__, 'edd_about_page'));

        if (!function_exists('WP_E_Sig')) {

            if (empty($GLOBALS['admin_page_hooks']['esign'])) {
                add_menu_page('E-Signature', 'E-Signature', 'read', "esign", array(__CLASS__, 'edd_about_page'), ESIGN_EDD_URL . '/assets/images/pen_icon.svg');
                add_submenu_page("esign", "Edd E-signature", "Edd E-signature", 'read', "esign", array(__CLASS__, 'edd_about_page'));
            }
            else {
                add_submenu_page("esign", "Edd E-signature", "Edd E-signature", 'read', "esign-edd-about", array(__CLASS__, 'edd_about_page'));
            }
            return;
        }


        $esigrole = new WP_E_Esigrole();
        if ($esigrole->esig_current_user_can('have_licenses')) {
            add_submenu_page(null, __('Esig EDD Settings Page', 'edd-esig'), __('Esig EDD Settings Page', 'edd-esig'), 'read', 'esign-edd', array(__CLASS__, 'esign_edd_view'));
            add_submenu_page(null, __('Esig EDD Core not installed', 'edd-esig'), __('Esig EDD Core not installed', 'edd-esig'), 'read', 'esign-not-core', array(__CLASS__, 'esign_not_core_view'));
        }
    }

    final static function edd_about_page() {
        //include easy digital download about page
        include_once(ESIGN_EDD_PATH . "/views/edd-esign-about.php");
    }

    final static function esig_core_page() {

        include_once(ESIGN_EDD_PATH . "/views/esig-core-about.php");
    }

    public function esign_not_core_view() {

        $template_data = array(
            "ESIGN_ASSETS_DIR_URI" => ESIGN_ASSETS_DIR_URI,
        );

        $branding_template = ESIGN_EDD_PATH . "/views/esig-not-core-view.php";
        WP_E_Sig()->view->renderPartial('', $template_data, true, '', $branding_template);
    }

}
